<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ne">
<context>
    <name>ReminderDialog</name>
    <message>
        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="35"/>
        <source>Restart the computer to use the system and the applications properly</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="36"/>
        <source>Make sure all data had been saved first</source>
        <translation>निश्चित गर्नुहोस् कि सबै डाटा पहिले बचत गरिएको थियो</translation>
    </message>
    <message>
        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="41"/>
        <source>Cancel</source>
        <translation>रद्द गर्नुहोस्</translation>
    </message>
    <message>
        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="41"/>
        <source>Shut down</source>
        <translation>बन्द गर्नुहोस्</translation>
    </message>
    <message>
        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="44"/>
        <source>Reboot</source>
        <translation>रिबुट गर्नुहोस्</translation>
    </message>
</context>
</TS>